struct	DPRSinfo{
	long int	Lat;
	long int	Long;
	char		AprsServerDomainName[128];
	in_port_t	Port;
	in_port_t	SmtpPort;
	char	CallSign[8];
	char	ValidCode[8];
	char	Comment[20];
	int	Interval;
	char	SmtpServer[40];
	char	User[16];
	char	Password[16];
	char	AltSSID[2];
	unsigned char smtpAuth		: 1;
	unsigned char 			: 1;
	unsigned char AutoReLink	: 1;
	unsigned char AutoLink		: 1;
	unsigned char ClientID		: 1;
	unsigned char 			: 1;
	unsigned char DprsStrip		: 1;
	unsigned char DprsSW 		: 1;
};

struct MessageSW {
		unsigned char : 5;
		unsigned char notfoundSW	: 1;
		unsigned char unlinkSW : 1;
		unsigned char connectSW : 1;
};	/* voice message SW */


struct	AprsCallTable{
	struct	AprsCallTable	*Next;
	char	CallSign[8];
	time_t	acc_time;
};

char	DprsTemp[512];
struct  MessageSW       Msg;
char	DprsMsgDstCallSign[10];
char	DprsMsgSrcCallSign[10];
char	AprsMessage[70];
char	AprsSenderCall[10];
char	DprsMsgDstCallSignSave[9];
char	AprsDest[9];
char	RadioDprsSend;
unsigned char	Radio_GPS_A_Msg_send;

long int	AprsSeq;
long int	RcvAprsSeq;
struct	AprsCallTable	*AprsCallTablePnt;

time_t	AprsMsgRecvTimer;
time_t	DprsBeaconTimer;
time_t	AprsRadioTimer;

struct	DPRSinfo	DPRS;

mqd_t        dprs_qid;
